@@ -1,5 +1,5 @@
 package Log::Log4perl::Layout::JSON;
-$Log::Log4perl::Layout::JSON::VERSION = '0.53';
+$Log::Log4perl::Layout::JSON::VERSION = '0.54';
 # ABSTRACT: Layout a log message as a JSON hash, including MDC data
 
 use 5.008;
@@ -25,6 +25,7 @@ use parent qw(Log::Log4perl::Layout);
 use Class::Tiny {
 
     prefix => "",
+    format_prefix => 0,
 
     codec => sub {
         return JSON::MaybeXS->new
@@ -78,11 +79,17 @@ use Class::Tiny {
         my $message_pattern = delete $fields->{message}; ##
         my @field_patterns = map { $_ => $fields->{$_}->{value} } sort keys %$fields;
         unshift @field_patterns, message => $message_pattern->{value}
-            if $message_pattern; ##
+            if $message_pattern;  ##
 
         return Log::Log4perl::Layout::PatternLayout->new(join $self->_separator, @field_patterns);
     },
 
+    # if format_prefix is true, the prefix is a PatternLayout that itself can be formatted
+    _prefix_layout => sub {
+        my $self = shift;
+
+        return Log::Log4perl::Layout::PatternLayout->new($self->prefix);
+    },
 };
 BEGIN { push our @ISA, 'Class::Tiny::Object' }
 
@@ -107,7 +114,7 @@ sub BUILD { ## no critic (RequireArgUnpacking)
     }
 
     for my $arg_name (qw(
-        canonical prefix include_mdc name_for_mdc max_json_length_kb
+        canonical prefix include_mdc name_for_mdc max_json_length_kb format_prefix
     )) {
         my $arg = delete $args->{$arg_name}
             or next;
@@ -253,7 +260,14 @@ sub render {
         }
     }
 
-    return $self->prefix . $json . "\n";
+    my $prefix = $self->prefix;
+
+    if ($self->format_prefix) {
+        return $self->_prefix_layout->render($message) . $json . "\n";
+    }
+    else {
+        return $self->prefix . $json . "\n";
+    }
 }
 
 1;
@@ -262,13 +276,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Log::Log4perl::Layout::JSON - Layout a log message as a JSON hash, including MDC data
 
 =head1 VERSION
 
-version 0.53
+version 0.54
 
 =head1 SYNOPSIS
 
@@ -321,6 +337,23 @@ Specify a prefix string for the JSON. For example:
 
 See http://blog.gerhards.net/2012/03/cee-enhanced-syslog-defined.html
 
+=head2 format_prefix
+
+If this is turned on, the prefix is treated as a
+L<Log::Log4perl::Layout::PatternLayout> string, and will be rendered as a
+pattern layout.
+
+For example:
+
+    log4perl.appender.Example.layout.prefix = %m{chomp} @cee: 
+    log4perl.appender.Example.layout.format_prefix = 1
+
+Would log C<Hello World> as:
+
+    Hello World @cee:{ .. MDC as JSON ... }
+
+See also L</prefix>
+
 =head2 include_mdc
 
 Include the data in the Log::Log4perl::MDC hash.
@@ -436,13 +469,17 @@ Originally created and maintained through v0.002003 by Tim Bunce.  Versions
 
 =head1 SOURCE
 
-The development version is on github at L<http://github.com/mschout/Log-Log4perl-Layout-JSON>
-and may be cloned from L<git://github.com/mschout/Log-Log4perl-Layout-JSON.git>
+The development version is on github at L<http://https://github.com/mschout/Log-Log4perl-Layout-JSON>
+and may be cloned from L<git://https://github.com/mschout/Log-Log4perl-Layout-JSON.git>
 
 =head1 BUGS
 
-Please report any bugs or feature requests to bug-log-log4perl-layout-json@rt.cpan.org or through the web interface at:
- http://rt.cpan.org/Public/Dist/Display.html?Name=Log-Log4perl-Layout-JSON
+Please report any bugs or feature requests on the bugtracker website
+L<https://github.com/mschout/Log-Log4perl-Layout-JSON/issues>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
 
 =head1 AUTHOR
 
